=======================================================
Dexterity Developer Manual
=======================================================

.. toctree::
   :maxdepth: 2

   intro.rst
   designing.rst
   prerequisite.rst
   schema-driven-types.rst
   model-driven-types.rst
   custom-views.rst
   advanced/index.rst
   testing/index.rst
   reference/index.rst

Appendixes
-------------------

.. toctree::
   :maxdepth: 1

   install.rst
   behaviors/index.rst
   grok/index.rst
